@@ -322,6 +322,9 @@ GLYPHS_UFO_CUSTOM_PARAMS = (
     # ('widthClass', 'openTypeOS2WidthClass'),
     # ('winAscent', 'openTypeOS2WinAscent'),
     # ('winDescent', 'openTypeOS2WinDescent'),
+    ("vheaVertAscender", "openTypeVheaVertTypoAscender"),
+    ("vheaVertDescender", "openTypeVheaVertTypoDescender"),
+    ("vheaVertLineGap", "openTypeVheaVertTypoLineGap"),
     ("vheaVertTypoAscender", "openTypeVheaVertTypoAscender"),
     ("vheaVertTypoDescender", "openTypeVheaVertTypoDescender"),
     ("vheaVertTypoLineGap", "openTypeVheaVertTypoLineGap"),
