@@ -14,7 +14,7 @@
 
 
 from glyphsLib import types
-from glyphsLib import classes
+from glyphsLib.classes import _to_glyphs_node_type
 
 
 def to_ufo_paths(self, ufo_glyph, layer):
@@ -83,11 +83,3 @@ def _to_ufo_node_type(node_type):
     if node_type not in ["line", "curve", "qcurve"]:
         return None
     return node_type
-
-
-def _to_glyphs_node_type(node_type):
-    if node_type is None:
-        return classes.OFFCURVE
-    if node_type == "move":
-        return classes.LINE
-    return node_type
