@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from copy import deepcopy
 import os.path
 
 import pytest
@@ -20,7 +21,7 @@ import pytest
 from fontTools import designspaceLib
 from glyphsLib import to_glyphs, to_designspace, to_ufos
 from glyphsLib.classes import GSFont, GSFontMaster
-from glyphsLib.builder.axes import get_regular_master
+from glyphsLib.builder.axes import _is_subset_of_default_axes, get_regular_master
 
 """
 Goal: check how files with custom axes are roundtripped.
@@ -46,6 +47,10 @@ Goal: check how files with custom axes are roundtripped.
             ("IJKL", "Third custom"),
             ("MNOP", "Fourth custom"),
         ],
+        [("opsz", "First custom"), ("wght", "Second custom")],
+        # Test that standard axis definitions don't generate an Axes custom parameter.
+        [("wght", "Weight"), ("wdth", "Width")],
+        [("wdth", "Width"), ("wght", "Weight")],
     ],
 )
 def test_weight_width_custom(axes, ufo_module):
@@ -56,9 +61,12 @@ def test_weight_width_custom(axes, ufo_module):
 
     font = to_glyphs(doc)
 
-    assert font.customParameters["Axes"] == [
-        {"Tag": tag, "Name": name} for tag, name in axes
-    ]
+    if _is_subset_of_default_axes([{"Name": n, "Tag": t} for t, n in axes]):
+        assert font.customParameters["Axes"] is None
+    else:
+        assert font.customParameters["Axes"] == [
+            {"Tag": tag, "Name": name} for tag, name in axes
+        ]
 
     doc = to_designspace(font, ufo_module=ufo_module)
 
@@ -81,6 +89,9 @@ def _make_designspace_with_axes(axes, ufo_module):
         axis = doc.newAxisDescriptor()
         axis.tag = tag
         axis.name = name
+        axis.minimum = 0
+        axis.default = 0
+        axis.maximum = 100
         doc.addAxis(axis)
 
         extreme = doc.newSourceDescriptor()
@@ -305,3 +316,102 @@ def test_single_master_default_weight_400(ufo_module):
 
     assert len(font2.masters) == 1
     assert font2.masters[0].weightValue == 400
+
+
+def test_axis_mapping(ufo_module):
+    font = to_glyphs(
+        [ufo_module.Font(), ufo_module.Font(), ufo_module.Font(), ufo_module.Font()]
+    )
+    font.masters[0].weightValue = 0
+    font.masters[0].widthValue = 100
+    font.masters[1].weightValue = 1000
+    font.masters[1].widthValue = 100
+
+    font.masters[2].weightValue = 0
+    font.masters[2].widthValue = 75
+    font.masters[3].weightValue = 1000
+    font.masters[3].widthValue = 75
+
+    wght_mapping = [(100, 0), (400, 350), (900, 1000)]
+    wdth_mapping = [(75, 75), (100, 100)]
+
+    axis_mappings = {
+        "wght": {str(float(k)): v for k, v in wght_mapping},
+        "wdth": {str(float(k)): v for k, v in wdth_mapping},
+    }
+
+    font.customParameters["Axis Mappings"] = axis_mappings
+    # When we convert to a designspace, the wdth mapping is removed because
+    # it isn't needed.
+    doc = to_designspace(font, ufo_module=ufo_module)
+
+    assert doc.axes[0].name == "Weight"
+    assert doc.axes[0].minimum == 100
+    assert doc.axes[0].default == 100
+    assert doc.axes[0].maximum == 900
+    assert doc.axes[0].map == wght_mapping
+
+    assert doc.axes[1].name == "Width"
+    assert doc.axes[1].minimum == 75
+    assert doc.axes[0].default == 100
+    assert doc.axes[1].maximum == 100
+    assert doc.axes[1].map != wdth_mapping
+    assert doc.axes[1].map == []
+
+    font = to_glyphs(doc)
+    assert font.customParameters["Axis Mappings"] == axis_mappings
+
+
+def test_axis_with_no_mapping_does_not_error_in_roundtrip(ufo_module):
+    """Tests that a custom axis without a mapping and without sources on its
+    extremes does not generate an error during roundtrip. Also tests that
+    during a to_glyphs, to_designspace roundtrip the min and max axis
+    information is not lost.
+    """
+    doc = designspaceLib.DesignSpaceDocument()
+
+    # Add a "Regular" source
+    regular = doc.newSourceDescriptor()
+    regular.font = ufo_module.Font()
+    regular.location = {"Style": 0}
+    doc.addSource(regular)
+
+    axis = doc.newAxisDescriptor()
+    axis.tag = "styl"
+    axis.name = "Style"
+    doc.addAxis(axis)
+
+    # This axis spans a range of 0 to 1 but only has a source at {"Style": 0}
+    # and no explicit mapping. The point of this test is to see if the min and
+    # max are still the same after round tripping.
+    doc.axes[0].minimum = 0
+    doc.axes[0].maximum = 1
+    doc.axes[0].default = 0
+    doc.axes[0].map = []
+
+    doc2 = deepcopy(doc)
+    font = to_glyphs(doc2)
+    doc_rt = to_designspace(font)
+
+    assert doc_rt.axes[0].serialize() == doc.axes[0].serialize()
+
+
+def test_axis_with_no_mapping_does_not_error_in_roundtrip_with_2_axes(ufo_module):
+    """Tests that a designspace with 2 axis, one with a mapping and one
+    without a mapping, roundtrips correctly without error. The axis without a
+    mapping should generate an identity mapping on the fly so that the
+    Glyphs.app customParameter field does not lose min/max infromation about
+    the axis.
+    """
+    doc = _make_designspace_with_axes(
+        [("wght", "Weight with mapping"), ("wdth", "Width without mapping")], ufo_module
+    )
+    # Add mapping to weight axis
+    doc.axes[0].map = [(0, 0), (50, 350), (100, 1000)]
+
+    doc2 = deepcopy(doc)
+    font = to_glyphs(doc2)
+    doc_rt = to_designspace(font)
+
+    assert doc_rt.axes[0].serialize() == doc.axes[0].serialize()
+    assert doc_rt.axes[1].serialize() == doc.axes[1].serialize()
